"""
Type annotations for ecr-public service client paginators.

[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ecr_public/paginators.html)

Usage::

    ```python
    import boto3

    from mypy_boto3_ecr_public import ECRPublicClient
    from mypy_boto3_ecr_public.paginator import (
        DescribeImageTagsPaginator,
        DescribeImagesPaginator,
        DescribeRegistriesPaginator,
        DescribeRepositoriesPaginator,
    )

    client: ECRPublicClient = boto3.client("ecr-public")

    describe_image_tags_paginator: DescribeImageTagsPaginator = client.get_paginator("describe_image_tags")
    describe_images_paginator: DescribeImagesPaginator = client.get_paginator("describe_images")
    describe_registries_paginator: DescribeRegistriesPaginator = client.get_paginator("describe_registries")
    describe_repositories_paginator: DescribeRepositoriesPaginator = client.get_paginator("describe_repositories")
    ```
"""
from typing import Iterator, List

from botocore.paginate import Paginator as Boto3Paginator

from mypy_boto3_ecr_public.type_defs import (
    DescribeImagesResponseTypeDef,
    DescribeImageTagsResponseTypeDef,
    DescribeRegistriesResponseTypeDef,
    DescribeRepositoriesResponseTypeDef,
    ImageIdentifierTypeDef,
    PaginatorConfigTypeDef,
)

__all__ = (
    "DescribeImageTagsPaginator",
    "DescribeImagesPaginator",
    "DescribeRegistriesPaginator",
    "DescribeRepositoriesPaginator",
)

class DescribeImageTagsPaginator(Boto3Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/ecr-public.html#ECRPublic.Paginator.DescribeImageTags)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ecr_public/paginators.html#describeimagetagspaginator)
    """

    def paginate(
        self,
        repositoryName: str,
        registryId: str = None,
        PaginationConfig: PaginatorConfigTypeDef = None,
    ) -> Iterator[DescribeImageTagsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/ecr-public.html#ECRPublic.Paginator.DescribeImageTags.paginate)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ecr_public/paginators.html#describeimagetagspaginator)
        """

class DescribeImagesPaginator(Boto3Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/ecr-public.html#ECRPublic.Paginator.DescribeImages)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ecr_public/paginators.html#describeimagespaginator)
    """

    def paginate(
        self,
        repositoryName: str,
        registryId: str = None,
        imageIds: List["ImageIdentifierTypeDef"] = None,
        PaginationConfig: PaginatorConfigTypeDef = None,
    ) -> Iterator[DescribeImagesResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/ecr-public.html#ECRPublic.Paginator.DescribeImages.paginate)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ecr_public/paginators.html#describeimagespaginator)
        """

class DescribeRegistriesPaginator(Boto3Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/ecr-public.html#ECRPublic.Paginator.DescribeRegistries)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ecr_public/paginators.html#describeregistriespaginator)
    """

    def paginate(
        self, PaginationConfig: PaginatorConfigTypeDef = None
    ) -> Iterator[DescribeRegistriesResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/ecr-public.html#ECRPublic.Paginator.DescribeRegistries.paginate)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ecr_public/paginators.html#describeregistriespaginator)
        """

class DescribeRepositoriesPaginator(Boto3Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/ecr-public.html#ECRPublic.Paginator.DescribeRepositories)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ecr_public/paginators.html#describerepositoriespaginator)
    """

    def paginate(
        self,
        registryId: str = None,
        repositoryNames: List[str] = None,
        PaginationConfig: PaginatorConfigTypeDef = None,
    ) -> Iterator[DescribeRepositoriesResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/ecr-public.html#ECRPublic.Paginator.DescribeRepositories.paginate)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ecr_public/paginators.html#describerepositoriespaginator)
        """



"""
Type annotations for ecr-public service literal definitions.

[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ecr_public/literals.html)

Usage::

    ```python
    from mypy_boto3_ecr_public.literals import DescribeImageTagsPaginatorName

    data: DescribeImageTagsPaginatorName = "describe_image_tags"
    ```
"""
import sys

if sys.version_info >= (3, 8):
    from typing import Literal
else:
    from typing_extensions import Literal


__all__ = (
    "DescribeImageTagsPaginatorName",
    "DescribeImagesPaginatorName",
    "DescribeRegistriesPaginatorName",
    "DescribeRepositoriesPaginatorName",
    "ImageFailureCode",
    "LayerAvailability",
    "LayerFailureCode",
    "RegistryAliasStatus",
)


DescribeImageTagsPaginatorName = Literal["describe_image_tags"]
DescribeImagesPaginatorName = Literal["describe_images"]
DescribeRegistriesPaginatorName = Literal["describe_registries"]
DescribeRepositoriesPaginatorName = Literal["describe_repositories"]
ImageFailureCode = Literal[
    "ImageNotFound",
    "ImageReferencedByManifestList",
    "ImageTagDoesNotMatchDigest",
    "InvalidImageDigest",
    "InvalidImageTag",
    "KmsError",
    "MissingDigestAndTag",
]
LayerAvailability = Literal["AVAILABLE", "UNAVAILABLE"]
LayerFailureCode = Literal["InvalidLayerDigest", "MissingLayerDigest"]
RegistryAliasStatus = Literal["ACTIVE", "PENDING", "REJECTED"]



"""
Type annotations for ecr-public service type definitions.

[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ecr_public/type_defs.html)

Usage::

    ```python
    from mypy_boto3_ecr_public.type_defs import AuthorizationDataTypeDef

    data: AuthorizationDataTypeDef = {...}
    ```
"""
import sys
from datetime import datetime
from typing import IO, List, Union

from mypy_boto3_ecr_public.literals import (
    ImageFailureCode,
    LayerAvailability,
    LayerFailureCode,
    RegistryAliasStatus,
)

if sys.version_info >= (3, 8):
    from typing import TypedDict
else:
    from typing_extensions import TypedDict

__all__ = (
    "AuthorizationDataTypeDef",
    "BatchCheckLayerAvailabilityResponseTypeDef",
    "BatchDeleteImageResponseTypeDef",
    "CompleteLayerUploadResponseTypeDef",
    "CreateRepositoryResponseTypeDef",
    "DeleteRepositoryPolicyResponseTypeDef",
    "DeleteRepositoryResponseTypeDef",
    "DescribeImageTagsResponseTypeDef",
    "DescribeImagesResponseTypeDef",
    "DescribeRegistriesResponseTypeDef",
    "DescribeRepositoriesResponseTypeDef",
    "GetAuthorizationTokenResponseTypeDef",
    "GetRegistryCatalogDataResponseTypeDef",
    "GetRepositoryCatalogDataResponseTypeDef",
    "GetRepositoryPolicyResponseTypeDef",
    "ImageDetailTypeDef",
    "ImageFailureTypeDef",
    "ImageIdentifierTypeDef",
    "ImageTagDetailTypeDef",
    "ImageTypeDef",
    "InitiateLayerUploadResponseTypeDef",
    "LayerFailureTypeDef",
    "LayerTypeDef",
    "ListTagsForResourceResponseTypeDef",
    "PaginatorConfigTypeDef",
    "PutImageResponseTypeDef",
    "PutRegistryCatalogDataResponseTypeDef",
    "PutRepositoryCatalogDataResponseTypeDef",
    "ReferencedImageDetailTypeDef",
    "RegistryAliasTypeDef",
    "RegistryCatalogDataTypeDef",
    "RegistryTypeDef",
    "RepositoryCatalogDataInputTypeDef",
    "RepositoryCatalogDataTypeDef",
    "RepositoryTypeDef",
    "SetRepositoryPolicyResponseTypeDef",
    "TagTypeDef",
    "UploadLayerPartResponseTypeDef",
)

class AuthorizationDataTypeDef(TypedDict, total=False):
    authorizationToken: str
    expiresAt: datetime

class BatchCheckLayerAvailabilityResponseTypeDef(TypedDict, total=False):
    layers: List["LayerTypeDef"]
    failures: List["LayerFailureTypeDef"]

class BatchDeleteImageResponseTypeDef(TypedDict, total=False):
    imageIds: List["ImageIdentifierTypeDef"]
    failures: List["ImageFailureTypeDef"]

class CompleteLayerUploadResponseTypeDef(TypedDict, total=False):
    registryId: str
    repositoryName: str
    uploadId: str
    layerDigest: str

class CreateRepositoryResponseTypeDef(TypedDict, total=False):
    repository: "RepositoryTypeDef"
    catalogData: "RepositoryCatalogDataTypeDef"

class DeleteRepositoryPolicyResponseTypeDef(TypedDict, total=False):
    registryId: str
    repositoryName: str
    policyText: str

class DeleteRepositoryResponseTypeDef(TypedDict, total=False):
    repository: "RepositoryTypeDef"

class DescribeImageTagsResponseTypeDef(TypedDict, total=False):
    imageTagDetails: List["ImageTagDetailTypeDef"]
    nextToken: str

class DescribeImagesResponseTypeDef(TypedDict, total=False):
    imageDetails: List["ImageDetailTypeDef"]
    nextToken: str

class _RequiredDescribeRegistriesResponseTypeDef(TypedDict):
    registries: List["RegistryTypeDef"]

class DescribeRegistriesResponseTypeDef(_RequiredDescribeRegistriesResponseTypeDef, total=False):
    nextToken: str

class DescribeRepositoriesResponseTypeDef(TypedDict, total=False):
    repositories: List["RepositoryTypeDef"]
    nextToken: str

class GetAuthorizationTokenResponseTypeDef(TypedDict, total=False):
    authorizationData: "AuthorizationDataTypeDef"

class GetRegistryCatalogDataResponseTypeDef(TypedDict):
    registryCatalogData: "RegistryCatalogDataTypeDef"

class GetRepositoryCatalogDataResponseTypeDef(TypedDict, total=False):
    catalogData: "RepositoryCatalogDataTypeDef"

class GetRepositoryPolicyResponseTypeDef(TypedDict, total=False):
    registryId: str
    repositoryName: str
    policyText: str

class ImageDetailTypeDef(TypedDict, total=False):
    registryId: str
    repositoryName: str
    imageDigest: str
    imageTags: List[str]
    imageSizeInBytes: int
    imagePushedAt: datetime
    imageManifestMediaType: str
    artifactMediaType: str

class ImageFailureTypeDef(TypedDict, total=False):
    imageId: "ImageIdentifierTypeDef"
    failureCode: ImageFailureCode
    failureReason: str

class ImageIdentifierTypeDef(TypedDict, total=False):
    imageDigest: str
    imageTag: str

class ImageTagDetailTypeDef(TypedDict, total=False):
    imageTag: str
    createdAt: datetime
    imageDetail: "ReferencedImageDetailTypeDef"

class ImageTypeDef(TypedDict, total=False):
    registryId: str
    repositoryName: str
    imageId: "ImageIdentifierTypeDef"
    imageManifest: str
    imageManifestMediaType: str

class InitiateLayerUploadResponseTypeDef(TypedDict, total=False):
    uploadId: str
    partSize: int

class LayerFailureTypeDef(TypedDict, total=False):
    layerDigest: str
    failureCode: LayerFailureCode
    failureReason: str

class LayerTypeDef(TypedDict, total=False):
    layerDigest: str
    layerAvailability: LayerAvailability
    layerSize: int
    mediaType: str

class ListTagsForResourceResponseTypeDef(TypedDict, total=False):
    tags: List["TagTypeDef"]

class PaginatorConfigTypeDef(TypedDict, total=False):
    MaxItems: int
    PageSize: int
    StartingToken: str

class PutImageResponseTypeDef(TypedDict, total=False):
    image: "ImageTypeDef"

class PutRegistryCatalogDataResponseTypeDef(TypedDict):
    registryCatalogData: "RegistryCatalogDataTypeDef"

class PutRepositoryCatalogDataResponseTypeDef(TypedDict, total=False):
    catalogData: "RepositoryCatalogDataTypeDef"

class ReferencedImageDetailTypeDef(TypedDict, total=False):
    imageDigest: str
    imageSizeInBytes: int
    imagePushedAt: datetime
    imageManifestMediaType: str
    artifactMediaType: str

class RegistryAliasTypeDef(TypedDict):
    name: str
    status: RegistryAliasStatus
    primaryRegistryAlias: bool
    defaultRegistryAlias: bool

class RegistryCatalogDataTypeDef(TypedDict, total=False):
    displayName: str

class RegistryTypeDef(TypedDict):
    registryId: str
    registryArn: str
    registryUri: str
    verified: bool
    aliases: List["RegistryAliasTypeDef"]

class RepositoryCatalogDataInputTypeDef(TypedDict, total=False):
    description: str
    architectures: List[str]
    operatingSystems: List[str]
    logoImageBlob: Union[bytes, IO[bytes]]
    aboutText: str
    usageText: str

class RepositoryCatalogDataTypeDef(TypedDict, total=False):
    description: str
    architectures: List[str]
    operatingSystems: List[str]
    logoUrl: str
    aboutText: str
    usageText: str
    marketplaceCertified: bool

class RepositoryTypeDef(TypedDict, total=False):
    repositoryArn: str
    registryId: str
    repositoryName: str
    repositoryUri: str
    createdAt: datetime

class SetRepositoryPolicyResponseTypeDef(TypedDict, total=False):
    registryId: str
    repositoryName: str
    policyText: str

class TagTypeDef(TypedDict, total=False):
    Key: str
    Value: str

class UploadLayerPartResponseTypeDef(TypedDict, total=False):
    registryId: str
    repositoryName: str
    uploadId: str
    lastByteReceived: int
